@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Optional, Set
+from typing import Any, Mapping, Optional, Sequence, Set
 
 import dagster._check as check
 from dagster import Permissive, resource
@@ -25,7 +25,7 @@ class DbtCliResource(DbtResource):
     def __init__(
         self,
         executable: str,
-        default_flags: Dict[str, Any],
+        default_flags: Mapping[str, Any],
         warn_error: bool,
         ignore_handled_error: bool,
         target_path: str,
@@ -45,7 +45,7 @@ class DbtCliResource(DbtResource):
         super().__init__(logger)
 
     @property
-    def default_flags(self) -> Dict[str, Any]:
+    def default_flags(self) -> Mapping[str, Any]:
         """
         A set of params populated from resource config that are passed as flags to each dbt CLI command.
         """
@@ -103,9 +103,9 @@ class DbtCliResource(DbtResource):
     @public
     def compile(
         self,
-        models: Optional[List[str]] = None,
-        exclude: Optional[List[str]] = None,
-        select: Optional[List[str]] = None,
+        models: Optional[Sequence[str]] = None,
+        exclude: Optional[Sequence[str]] = None,
+        select: Optional[Sequence[str]] = None,
         **kwargs,
     ) -> DbtCliOutput:
         """
@@ -125,9 +125,9 @@ class DbtCliResource(DbtResource):
     @public
     def run(
         self,
-        models: Optional[List[str]] = None,
-        exclude: Optional[List[str]] = None,
-        select: Optional[List[str]] = None,
+        models: Optional[Sequence[str]] = None,
+        exclude: Optional[Sequence[str]] = None,
+        select: Optional[Sequence[str]] = None,
         **kwargs,
     ) -> DbtCliOutput:
         """
@@ -146,7 +146,10 @@ class DbtCliResource(DbtResource):
 
     @public
     def snapshot(
-        self, select: Optional[List[str]] = None, exclude: Optional[List[str]] = None, **kwargs
+        self,
+        select: Optional[Sequence[str]] = None,
+        exclude: Optional[Sequence[str]] = None,
+        **kwargs,
     ) -> DbtCliOutput:
         """
         Run the ``snapshot`` command on a dbt project. kwargs are passed in as additional parameters.
@@ -164,11 +167,11 @@ class DbtCliResource(DbtResource):
     @public
     def test(
         self,
-        models: Optional[List[str]] = None,
-        exclude: Optional[List[str]] = None,
+        models: Optional[Sequence[str]] = None,
+        exclude: Optional[Sequence[str]] = None,
         data: bool = True,
         schema: bool = True,
-        select: Optional[List[str]] = None,
+        select: Optional[Sequence[str]] = None,
         **kwargs,
     ) -> DbtCliOutput:
         """
@@ -204,8 +207,8 @@ class DbtCliResource(DbtResource):
     def seed(
         self,
         show: bool = False,
-        select: Optional[List[str]] = None,
-        exclude: Optional[List[str]] = None,
+        select: Optional[Sequence[str]] = None,
+        exclude: Optional[Sequence[str]] = None,
         **kwargs,
     ) -> DbtCliOutput:
         """
@@ -226,9 +229,9 @@ class DbtCliResource(DbtResource):
     @public
     def ls(
         self,
-        select: Optional[List[str]] = None,
-        models: Optional[List[str]] = None,
-        exclude: Optional[List[str]] = None,
+        select: Optional[Sequence[str]] = None,
+        models: Optional[Sequence[str]] = None,
+        exclude: Optional[Sequence[str]] = None,
         **kwargs,
     ) -> DbtCliOutput:
         """
@@ -246,7 +249,7 @@ class DbtCliResource(DbtResource):
         return self.cli("ls", select=select, models=models, exclude=exclude, **kwargs)
 
     @public
-    def build(self, select: Optional[List[str]] = None, **kwargs) -> DbtCliOutput:
+    def build(self, select: Optional[Sequence[str]] = None, **kwargs) -> DbtCliOutput:
         """
         Run the ``build`` command on a dbt project. kwargs are passed in as additional parameters.
 
@@ -260,7 +263,7 @@ class DbtCliResource(DbtResource):
         return self.cli("build", select=select, **kwargs)
 
     @public
-    def freshness(self, select: Optional[List[str]] = None, **kwargs) -> DbtCliOutput:
+    def freshness(self, select: Optional[Sequence[str]] = None, **kwargs) -> DbtCliOutput:
         """
         Run the ``source snapshot-freshness`` command on a dbt project. kwargs are passed in as additional parameters.
 
@@ -289,7 +292,7 @@ class DbtCliResource(DbtResource):
 
     @public
     def run_operation(
-        self, macro: str, args: Optional[Dict[str, Any]] = None, **kwargs
+        self, macro: str, args: Optional[Mapping[str, Any]] = None, **kwargs
     ) -> DbtCliOutput:
         """
         Run the ``run-operation`` command on a dbt project. kwargs are passed in as additional parameters.
@@ -306,7 +309,7 @@ class DbtCliResource(DbtResource):
         return self.cli(f"run-operation {macro}", args=args, **kwargs)
 
     @public
-    def get_run_results_json(self, **kwargs) -> Optional[Dict[str, Any]]:
+    def get_run_results_json(self, **kwargs) -> Optional[Mapping[str, Any]]:
         """
         Get a parsed version of the run_results.json file for the relevant dbt project.
 
@@ -328,7 +331,7 @@ class DbtCliResource(DbtResource):
         remove_run_results(project_dir, target_path)
 
     @public
-    def get_manifest_json(self, **kwargs) -> Optional[Dict[str, Any]]:
+    def get_manifest_json(self, **kwargs) -> Optional[Mapping[str, Any]]:
         """
         Get a parsed version of the manifest.json file for the relevant dbt project.
 
