@@ -2,13 +2,13 @@ import datetime
 import json
 import logging
 import time
-from typing import Any, Dict, List, Optional, cast
+from typing import Any, Mapping, Optional, Sequence, cast
 from urllib.parse import urlencode, urljoin
 
 import requests
 from requests.exceptions import RequestException
 
-from dagster import Failure, Field, MetadataValue, StringSource, __version__
+from dagster import Failure, Field, IntSource, MetadataValue, StringSource, __version__
 from dagster import _check as check
 from dagster import get_dagster_logger, resource
 from dagster._utils.merger import deep_merge_dicts
@@ -55,11 +55,23 @@ class DbtCloudResourceV2:
     def api_base_url(self) -> str:
         return urljoin(self._dbt_cloud_host, DBT_ACCOUNTS_PATH)
 
+    def build_url_for_job(self, project_id: int, job_id: int) -> str:
+        return urljoin(
+            self._dbt_cloud_host,
+            f"next/deploy/{self._account_id}/projects/{project_id}/jobs/{job_id}/",
+        )
+
+    def build_url_for_cloud_docs(self, job_id: int, resource_type: str, unique_id: str) -> str:
+        return urljoin(
+            self._dbt_cloud_host,
+            f"/accounts/{self._account_id}/jobs/{job_id}/docs/#!/{resource_type}/{unique_id}",
+        )
+
     def make_request(
         self,
         method: str,
         endpoint: str,
-        data: Optional[Dict[str, Any]] = None,
+        data: Optional[Mapping[str, Any]] = None,
         return_text: bool = False,
     ) -> Any:
         """
@@ -106,7 +118,7 @@ class DbtCloudResourceV2:
 
         raise Failure("Exceeded max number of retries.")
 
-    def get_job(self, job_id: int) -> Dict[str, Any]:
+    def get_job(self, job_id: int) -> Mapping[str, Any]:
         """
         Gets details about a given dbt job from the dbt Cloud API.
 
@@ -119,7 +131,7 @@ class DbtCloudResourceV2:
         """
         return self.make_request("GET", f"{self._account_id}/jobs/{job_id}/")
 
-    def update_job(self, job_id: int, **kwargs) -> Dict[str, Any]:
+    def update_job(self, job_id: int, **kwargs) -> Mapping[str, Any]:
         """
         Updates specific properties of a dbt job. Documentation on the full set of potential
         parameters can be found here: https://docs.getdbt.com/dbt-cloud/api-v2#operation/updateJobById
@@ -146,7 +158,7 @@ class DbtCloudResourceV2:
             "POST", f"{self._account_id}/jobs/{job_id}/", data=deep_merge_dicts(job_data, kwargs)
         )
 
-    def run_job(self, job_id: int, **kwargs) -> Dict[str, Any]:
+    def run_job(self, job_id: int, **kwargs) -> Mapping[str, Any]:
         """
         Initializes a run for a job. Overrides for specific properties can be set by passing in
         values to the kwargs. A full list of overridable properties can be found here:
@@ -176,12 +188,12 @@ class DbtCloudResourceV2:
 
     def get_runs(
         self,
-        include_related: Optional[List[str]] = None,
+        include_related: Optional[Sequence[str]] = None,
         job_id: Optional[int] = None,
         order_by: Optional[str] = "-id",
         offset: int = 0,
         limit: int = 100,
-    ) -> List[Dict[str, object]]:
+    ) -> Sequence[Mapping[str, object]]:
         """
         Returns a list of runs from dbt Cloud. This can be optionally filtered to a specific job
         using the job_definition_id. It supports pagination using offset and limit as well and
@@ -217,7 +229,9 @@ class DbtCloudResourceV2:
             query_dict["job_definition_id"] = job_id
         return self.make_request("GET", f"{self._account_id}/runs/?{urlencode(query_dict)}")
 
-    def get_run(self, run_id: int, include_related: Optional[List[str]] = None) -> Dict[str, Any]:
+    def get_run(
+        self, run_id: int, include_related: Optional[Sequence[str]] = None
+    ) -> Mapping[str, Any]:
         """
         Gets details about a specific job run.
 
@@ -238,7 +252,7 @@ class DbtCloudResourceV2:
             f"{self._account_id}/runs/{run_id}/{query_params}",
         )
 
-    def get_run_steps(self, run_id: int) -> List[str]:
+    def get_run_steps(self, run_id: int) -> Sequence[str]:
         """
         Gets the steps of an initialized dbt Cloud run.
 
@@ -255,7 +269,7 @@ class DbtCloudResourceV2:
         steps_override = run_details["trigger"]["steps_override"]
         return steps_override or steps
 
-    def cancel_run(self, run_id: int) -> Dict[str, Any]:
+    def cancel_run(self, run_id: int) -> Mapping[str, Any]:
         """
         Cancels a dbt Cloud run.
 
@@ -271,7 +285,7 @@ class DbtCloudResourceV2:
         self._log.info(f"Cancelling run with id '{run_id}'")
         return self.make_request("POST", f"{self._account_id}/runs/{run_id}/cancel/")
 
-    def list_run_artifacts(self, run_id: int, step: Optional[int] = None) -> List[str]:
+    def list_run_artifacts(self, run_id: int, step: Optional[int] = None) -> Sequence[str]:
         """
         Lists the paths of the available run artifacts from a completed dbt Cloud run.
 
@@ -320,7 +334,7 @@ class DbtCloudResourceV2:
             return_text=True,
         )["text"]
 
-    def get_manifest(self, run_id: int, step: Optional[int] = None) -> Dict[str, Any]:
+    def get_manifest(self, run_id: int, step: Optional[int] = None) -> Mapping[str, Any]:
         """
         The parsed contents of a manifest.json file created by a completed run.
 
@@ -337,7 +351,7 @@ class DbtCloudResourceV2:
         """
         return json.loads(self.get_run_artifact(run_id, "manifest.json", step=step))
 
-    def get_run_results(self, run_id: int, step: Optional[int] = None) -> Dict[str, Any]:
+    def get_run_results(self, run_id: int, step: Optional[int] = None) -> Mapping[str, Any]:
         """
         The parsed contents of a run_results.json file created by a completed run.
 
@@ -360,7 +374,7 @@ class DbtCloudResourceV2:
         poll_interval: float = DEFAULT_POLL_INTERVAL,
         poll_timeout: Optional[float] = None,
         href: Optional[str] = None,
-    ) -> Dict[str, Any]:
+    ) -> Mapping[str, Any]:
         """
         Polls a dbt Cloud job run until it completes. Will raise a `dagster.Failure` exception if the
         run does not complete successfully.
@@ -393,7 +407,7 @@ class DbtCloudResourceV2:
 
             # completed successfully
             if status == "Success":
-                return self.get_run(run_id, include_related=["job", "trigger"])
+                return self.get_run(run_id, include_related=["job", "trigger", "run_steps"])
             elif status in ["Error", "Cancelled"]:
                 break
             elif status not in ["Queued", "Starting", "Running"]:
@@ -426,6 +440,7 @@ class DbtCloudResourceV2:
         job_id: int,
         poll_interval: float = DEFAULT_POLL_INTERVAL,
         poll_timeout: Optional[float] = None,
+        **kwargs,
     ) -> DbtCloudOutput:
         """
         Runs a dbt Cloud job and polls until it completes. Will raise a `dagster.Failure` exception
@@ -445,13 +460,21 @@ class DbtCloudResourceV2:
             :py:class:`~DbtCloudOutput`: Class containing details about the specific job run and the
                 parsed run results.
         """
-        run_details = self.run_job(job_id)
+        run_details = self.run_job(job_id, **kwargs)
         run_id = run_details["id"]
         href = run_details["href"]
         final_run_details = self.poll_run(
             run_id, poll_interval=poll_interval, poll_timeout=poll_timeout, href=href
         )
-        output = DbtCloudOutput(run_details=final_run_details, result=self.get_run_results(run_id))
+        try:
+            run_results = self.get_run_results(run_id)
+        # if you fail to get run_results for this job, just leave it empty
+        except Failure as _:
+            self._log.info(
+                "run_results.json not available for this run. Defaulting to empty value."
+            )
+            run_results = {}
+        output = DbtCloudOutput(run_details=final_run_details, result=run_results)
         if output.docs_url:
             self._log.info(f"Docs for this run can be viewed here: {output.docs_url}")
         return output
@@ -468,7 +491,7 @@ class DbtCloudResourceV2:
             "for instructions on creating a Service Account token.",
         ),
         "account_id": Field(
-            int,
+            IntSource,
             is_required=True,
             description="dbt Cloud Account ID. This value can be found in the url of a variety of "
             "views in the dbt Cloud UI, e.g. https://cloud.getdbt.com/#/accounts/{account_id}/settings/.",
@@ -520,11 +543,11 @@ def dbt_cloud_resource(context) -> DbtCloudResourceV2:
         my_dbt_cloud_resource = dbt_cloud_resource.configured(
             {
                 "auth_token": {"env": "DBT_CLOUD_AUTH_TOKEN"},
-                "account_id": 30000,
+                "account_id": {"env": "DBT_CLOUD_ACCOUNT_ID"},
             }
         )
 
-        @job(resource_defs={"dbt_cloud":my_dbt_cloud_resource})
+        @job(resource_defs={"dbt_cloud": my_dbt_cloud_resource})
         def my_dbt_cloud_job():
             ...
     """
